|
Boost-Commit : |
From: dgregor_at_[hidden]
Date: 2007-09-13 14:43:00
Author: dgregor
Date: 2007-09-13 14:43:00 EDT (Thu, 13 Sep 2007)
New Revision: 39242
URL: http://svn.boost.org/trac/boost/changeset/39242
Log:
Update the nag script to use Subversion
Text files modified:
trunk/tools/regression/xsl_reports/email_maintainers.py | 39 ++++++++++++++++++++-------------------
1 files changed, 20 insertions(+), 19 deletions(-)
Modified: trunk/tools/regression/xsl_reports/email_maintainers.py
==============================================================================
--- trunk/tools/regression/xsl_reports/email_maintainers.py (original)
+++ trunk/tools/regression/xsl_reports/email_maintainers.py 2007-09-13 14:43:00 EDT (Thu, 13 Sep 2007)
@@ -14,7 +14,7 @@
import datetime
import sys
-report_author = "Douglas Gregor <dgregor_at_[hidden]>"
+report_author = "Douglas Gregor <dgregor_at_[hidden]>"
boost_dev_list = "Boost Developer List <boost_at_[hidden]>"
def sorted_keys( dict ):
@@ -150,12 +150,12 @@
return None
# Build the message header
- message = """From: Douglas Gregor <dgregor_at_[hidden]>
+ message = """From: Douglas Gregor <dgregor_at_[hidden]>
To: """
message += self.name + ' <' + self.email + '>'
message += """
Reply-To: boost_at_[hidden]
-Subject: Regressions in your Boost libraries as of """
+Subject: Failures in your Boost libraries as of """
message += str(datetime.date.today()) + " [" + report.branch + "]"
message += """
@@ -204,7 +204,7 @@
"""
The complete report of all failing test cases.
"""
- def __init__(self, branch = 'HEAD'):
+ def __init__(self, branch = 'trunk'):
self.branch = branch
self.date = None
self.url = None
@@ -287,11 +287,12 @@
def getIssuesEmail(self):
"""
- Retrieve the issues email from MetaComm, trying a few times in
- case something wonky is happening. If we can retrieve the file,
- calls parseIssuesEmail and return True; otherwise, return False.
+ Retrieve the issues email from beta.boost.org, trying a few
+ times in case something wonky is happening. If we can retrieve
+ the file, calls parseIssuesEmail and return True; otherwise,
+ return False.
"""
- base_url = "http://engineering.meta-comm.com/boost-regression/CVS-"
+ base_url = "http://beta.boost.org/development/tests/"
base_url += self.branch
base_url += "/developer/";
got_issues = False
@@ -372,11 +373,11 @@
To: boost_at_[hidden]
Reply-To: boost_at_[hidden]
Subject: [Report] """
- message += str(self.numFailures()) + " regressions on " + branch
+ message += str(self.numFailures()) + " failures on " + branch
message += " (" + str(datetime.date.today()) + ")"
message += """
-Boost Regression test failures
+Boost regression test failures
"""
message += "Report time: " + self.date + """
@@ -504,7 +505,7 @@
if '--send' in sys.argv:
print "Sending..."
smtp = smtplib.SMTP('milliways.osl.iu.edu')
- smtp.sendmail(from_addr = 'Douglas Gregor <dgregor_at_[hidden]>',
+ smtp.sendmail(from_addr = 'Douglas Gregor <dgregor_at_[hidden]>',
to_addrs = person[1],
msg = message)
print "Done."
@@ -513,12 +514,12 @@
# Send a message to the developer's list
def send_boost_developers_message(branch, maintainers, failing_libraries):
to_line = 'boost_at_[hidden]'
- from_line = 'Douglas Gregor <dgregor_at_[hidden]>'
+ from_line = 'Douglas Gregor <dgregor_at_[hidden]>'
- message = """From: Douglas Gregor <dgregor_at_[hidden]>
+ message = """From: Douglas Gregor <dgregor_at_[hidden]>
To: boost_at_[hidden]
Reply-To: boost_at_[hidden]
-Subject: Boost regression notification ("""
+Subject: Boost regression testing notification ("""
message += str(datetime.date.today()) + " [" + branch + "]"
message += ")"
@@ -564,7 +565,7 @@
###############################################################################
# Parse command-line options
-branch = "HEAD"
+branch = "trunk"
for arg in sys.argv:
if arg.startswith("--branch="):
branch = arg[len("--branch="):]
@@ -580,14 +581,14 @@
if not okay:
print 'Aborting.'
if '--send' in sys.argv:
- message = """From: Douglas Gregor <dgregor_at_[hidden]>
- To: Douglas Gregor <dgregor_at_[hidden]>
+ message = """From: Douglas Gregor <dgregor_at_[hidden]>
+ To: Douglas Gregor <dgregor_at_[hidden]>
Reply-To: boost_at_[hidden]
Subject: Regression status script failed on """
message += str(datetime.date.today()) + " [" + branch + "]"
smtp = smtplib.SMTP('milliways.osl.iu.edu')
- smtp.sendmail(from_addr = 'Douglas Gregor <dgregor_at_[hidden]>',
- to_addrs = 'dgregor_at_[hidden]',
+ smtp.sendmail(from_addr = 'Douglas Gregor <dgregor_at_[hidden]>',
+ to_addrs = 'dgregor_at_[hidden]',
msg = message)
sys.exit(1)
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk